@@ -181,7 +181,7 @@ class LambdaToSecretsmanager(
             vpc_props=vpc_props,
         )
 
-        jsii.create(LambdaToSecretsmanager, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
